.. :changelog:

History
-------

0.3.0 (2017-05-26)
++++++++++++++++++

* Fork of the project to maintain development
* Drop Py26, Py33 and Py34 support
* Drop DRF<3.0 support

0.1.0 (2013-12-20)
++++++++++++++++++

* First release on PyPI.
